@@ -11,7 +11,8 @@ sub new {
 
 # The main method for this process class.
 sub process{
-  my $self = shift if ref $_[0] eq __PACKAGE__;
+  my $self = shift if ($_[0] && ref $_[0] eq __PACKAGE__);
+  my $self_module_name = shift if ($_[0] && $_[0] eq __PACKAGE__);
   my $model = keys %{ $self->{model} } ? $self->{model} : $model;
 
   my $param = shift;
@@ -58,6 +59,7 @@ sub scalar_filter{
 
 sub model{
   my $self = shift if ref $_[0] eq __PACKAGE__;
+  my $self_module_name = shift if $_[0] eq __PACKAGE__;
   my $arg = shift;
   if ($arg) {
     if ($self) { $self->{model} = $arg; }
